@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: Xrm.cc,v 1.5 1997/03/10 22:57:37 bgrayson Exp $
+// $Id: Xrm.cc,v 1.6 1997/11/04 19:51:38 mromberg Exp $
 //
 
 #include <string.h>
@@ -17,7 +17,7 @@
 #include "Xrm.h"
 #include "Xrmcommandline.h"
 
-CVSID("$Id: Xrm.cc,v 1.5 1997/03/10 22:57:37 bgrayson Exp $");
+CVSID("$Id: Xrm.cc,v 1.6 1997/11/04 19:51:38 mromberg Exp $");
 CVSID_DOT_H(XRM_H_CVSID);
 CVSID_DOT_H2(XRMCOMMANDLINE_H_CVSID);
 
@@ -157,7 +157,9 @@ Listed from weakest to strongest:
   {
     char xappfile[1024];
     sprintf (xappfile, "%s/%s", xappdir, className());
-    if (!access (xappfile, X_OK | R_OK))
+    // this did not work for XAPPLRESDIR
+    //if (!access (xappfile, X_OK | R_OK))  
+    if (!access (xappfile, R_OK))
     {
       XrmCombineFileDatabase (xappfile, &_db, 1);
       }
