@@ -1,11 +1,11 @@
 //
-// $Id: Xrmcommandline.h,v 1.11 1997/10/19 20:35:36 mromberg Exp $
+// $Id: Xrmcommandline.h,v 1.15 1998/05/17 21:26:19 bgrayson Exp $
 //
 
 #ifndef _Xrmcommandline_h
 #define _Xrmcommandline_h
 
-#define XRMCOMMANDLINE_H_CVSID "$Id: Xrmcommandline.h,v 1.11 1997/10/19 20:35:36 mromberg Exp $"
+#define XRMCOMMANDLINE_H_CVSID "$Id: Xrmcommandline.h,v 1.15 1998/05/17 21:26:19 bgrayson Exp $"
 
 #include <X11/Xresource.h>
 
@@ -26,6 +26,10 @@ static XrmOptionDescRec options[] = {
 { "+labels", "*labels", XrmoptionNoArg, "True" },
 { "-usedlabels", "*usedlabels", XrmoptionNoArg, "False" },
 { "+usedlabels", "*usedlabels", XrmoptionNoArg, "True" },
+//  This next one is not yet supported.
+#if 0
+{ "-samplesPerSec", "*samplesPerSec", XrmoptionSepArg, (caddr_t) NULL },
+#endif
 //  CPU resources
 { "-cpu", "*cpu", XrmoptionNoArg, "False" },
 { "+cpu", "*cpu", XrmoptionNoArg, "True" },
@@ -49,20 +53,27 @@ static XrmOptionDescRec options[] = {
 //  on/off flag.  Now, we have -net for on/off, and networkBandwidth
 //  for bandwidth, with the alias networkBW, and network for backwards
 //  compatibility.
-{ "-network", "*networkBandwidth", XrmoptionSepArg, (caddr_t) NULL },
-{ "-networkBW", "*networkBandwidth", XrmoptionSepArg, (caddr_t) NULL },
-{ "-networkBandwidth", "*networkBandwidth", XrmoptionSepArg, (caddr_t) NULL },
+{ "-network", "*netBandwidth", XrmoptionSepArg, (caddr_t) NULL },
+{ "-networkBW", "*netBandwidth", XrmoptionSepArg, (caddr_t) NULL },
+{ "-networkBandwidth", "*netBandwidth", XrmoptionSepArg, (caddr_t) NULL },
 
 // Page Meter
 { "-page", "*page", XrmoptionNoArg, "False" },
 { "+page", "*page", XrmoptionNoArg, "True" },
 { "-pagespeed", "*pageBandWidth", XrmoptionSepArg, (caddr_t) NULL },
 
-#ifdef XOSVIEW_NETBSD
+#if defined(XOSVIEW_NETBSD) || defined(XOSVIEW_FREEBSD) || defined(XOSVIEW_OPENBSD)
 //  Disk Meter Options
 { "-disk", "*disk", XrmoptionNoArg, "False" },
 { "+disk", "*disk", XrmoptionNoArg, "True" },
 #endif
+// Interrupt meter resources  --  all sorts of aliases.
+{ "-int", "*interrupts", XrmoptionNoArg, "False" },
+{ "+int", "*interrupts", XrmoptionNoArg, "True" },
+{ "-ints", "*interrupts", XrmoptionNoArg, "False" },
+{ "+ints", "*interrupts", XrmoptionNoArg, "True" },
+{ "-interrupts", "*interrupts", XrmoptionNoArg, "False" },
+{ "+interrupts", "*interrupts", XrmoptionNoArg, "True" },
 //  Special, catch-all option here --
 //    xosview -xrm "*memFreeColor: purple" should work, for example.
 { "-xrm", "*xrm", XrmoptionResArg, (caddr_t) NULL },
