@@ -4,32 +4,38 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: bitmeter.cc,v 1.3 1996/11/19 04:01:08 bgrayson Exp $
+// $Id: bitmeter.cc,v 1.6 1998/04/06 20:09:29 bgrayson Exp $
 //
 #include "general.h"
 #include "bitmeter.h"
 #include "xosview.h"
 
-CVSID("$Id: bitmeter.cc,v 1.3 1996/11/19 04:01:08 bgrayson Exp $");
+CVSID("$Id: bitmeter.cc,v 1.6 1998/04/06 20:09:29 bgrayson Exp $");
 CVSID_DOT_H(BITMETER_H_CVSID);
 
-
 BitMeter::BitMeter( XOSView *parent,
 		    const char *title, const char *legend, int numBits,
 		    int, int dousedlegends)
-: Meter( parent, title, legend, dousedlegends, dousedlegends ) {
-  numbits_ = numBits;
-
-  bits_ = new char[numbits_];
-  lastbits_ = new char[numbits_];
-
-  for ( int i = 0 ; i < numbits_ ; i++ )
-    bits_[i] = lastbits_[i] = 0;
+  : Meter( parent, title, legend, dousedlegends, dousedlegends ),
+  bits_(NULL), lastbits_(NULL)  {
+  setNumBits(numBits); 
 }
 
 BitMeter::~BitMeter( void ){
-  delete bits_;
-  delete lastbits_;
+  delete [] bits_;
+  delete [] lastbits_;
+}
+
+void BitMeter::setNumBits(int n){
+  numbits_ = n;
+  delete [] bits_;
+  delete [] lastbits_;
+
+  bits_ = new char[numbits_];
+  lastbits_ = new char[numbits_];
+  
+  for ( int i = 0 ; i < numbits_ ; i++ )
+      bits_[i] = lastbits_[i] = 0;
 }
 
 void BitMeter::checkResources( void ){
@@ -49,9 +55,9 @@ void BitMeter::drawBits( int manditory ){
 
   for ( int i = 0 ; i < numbits_ ; i++ ){
     if ( i != (numbits_ - 1) )
-      x2 = x_ + ((i + 1) * width_) / numbits_ - 1;
+      x2 = x_ + ((i + 1) * (width_+1)) / numbits_ - 1;
     else
-      x2 = x_ + width_ - 1;
+      x2 = x_ + (width_+1) - 1;
     
     if ( (bits_[i] != lastbits_[i]) || manditory ){
       if ( bits_[i] && pass )
@@ -69,14 +75,10 @@ void BitMeter::drawBits( int manditory ){
 }
 
 void BitMeter::draw( void ){
-  parent_->lineWidth( 2 );
+  parent_->lineWidth( 1 );
   parent_->setForeground( parent_->foreground() );
-  parent_->drawRectangle( x_ - 1, y_ - 1, width_ + 1, height_ + 1 );
+  parent_->drawFilledRectangle( x_ -1, y_ - 1, width_ + 2, height_ + 1 );
 
-  for ( int i = 1 ; i < numbits_ ; i++ ){
-    int x = x_ + (i * width_) / numbits_;
-    parent_->drawLine( x, y_, x, y_ + height_ );
-  }
   parent_->lineWidth( 0 );
 
   if ( dolegends_ ){
@@ -89,6 +91,7 @@ void BitMeter::draw( void ){
       offset = parent_->textWidth( "XXXXX" );
     
     parent_->drawString( x_ - offset, y_ + height_, title_ );
+    parent_->setForeground( onColor_ );
     parent_->drawString( x_, y_ - 5, legend_ );
   }
 
