@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: fieldmeter.cc,v 1.9 1997/01/14 17:44:45 bgrayson Exp $
+// $Id: fieldmeter.cc,v 1.15 1998/04/07 13:15:47 bgrayson Exp $
 //
 #include <fstream.h>
 #include <stdio.h>
@@ -12,7 +12,7 @@
 #include "fieldmeter.h"
 #include "xosview.h"
 
-CVSID("$Id: fieldmeter.cc,v 1.9 1997/01/14 17:44:45 bgrayson Exp $");
+CVSID("$Id: fieldmeter.cc,v 1.15 1998/04/07 13:15:47 bgrayson Exp $");
 CVSID_DOT_H(FIELDMETER_H_CVSID);
 
 FieldMeter::FieldMeter( XOSView *parent, int numfields, const char *title, 
@@ -21,6 +21,7 @@ FieldMeter::FieldMeter( XOSView *parent, int numfields, const char *title,
     /*  We need to set print_ to something valid -- the meters
      *  apparently get drawn before the meters have a chance to call
      *  CheckResources() themselves.  */
+  printedZeroTotalMesg_ = 0;
   print_ = PERCENT;
   used_ = 0;
   lastused_ = -1;
@@ -75,7 +76,20 @@ void FieldMeter::setUsed (float val, float total)
   if (print_ == FLOAT)
     used_ = val;
   else if (print_ == PERCENT)
-    used_ = val / total * 100.0;
+  {
+    if (total != 0.0)
+      used_ = val / total * 100.0;
+    else
+    {
+      if (!printedZeroTotalMesg_) {
+        printedZeroTotalMesg_ = 1;
+	fprintf(stderr, "Warning:  %s meter had a zero total "
+		"field!  Would have caused a div-by-zero "
+		"exception.\n", name());
+      }
+      used_ = 0.0;
+    }
+  }
   else if (print_ == AUTOSCALE)
     used_ = val;
   else {
@@ -172,9 +186,15 @@ void FieldMeter::drawused( int manditory ){
        *  999.5, if not rounded up to 1.0 K, will be rounded by the
        *  %.0f to be 1000, which is too wide.  So anything at or above
        *  999.5 needs to be bumped up.  */
-    if (used_ >= 999.5*1000*1000)
+    if (used_ >= 999.5*1000*1000*1000*1000*1000*1000)
+	{scale='E'; scaled_used = used_/1024/1024/1024/1024/1024/1024;}
+    else if (used_ >= 999.5*1000*1000*1000*1000)
+	{scale='P'; scaled_used = used_/1024/1024/1024/1024/1024;}
+    else if (used_ >= 999.5*1000*1000*1000)
+	{scale='T'; scaled_used = used_/1024/1024/1024/1024;}
+    else if (used_ >= 999.5*1000*1000)
 	{scale='G'; scaled_used = used_/1024/1024/1024;}
-    if (used_ >= 999.5*1000)
+    else if (used_ >= 999.5*1000)
 	{scale='M'; scaled_used = used_/1024/1024;}
     else if (used_ >= 999.5)
 	{scale='K'; scaled_used = used_/1024;}
@@ -262,7 +282,7 @@ bool FieldMeter::checkX(int x, int width) const {
     cerr << "FieldMeter::checkX() : bad horiz values for meter : "
          << name() << endl;
 
-    cerr <<"total_ = " <<total_ <<endl;
+    cerr <<"value "<<x<<", width "<<width<<", total_ = "<<total_<<endl;
 
     for (int i = 0 ; i < numfields_ ; i++)
       cerr <<"fields_[" <<i <<"] = " <<fields_[i] <<",";
