@@ -1,23 +1,27 @@
 //  
-//  Copyright (c) 1994 by Mike Romberg (  romberg@md.fsl.noaa.gov )
+//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-
+//
+// $Id: cpumeter.h,v 1.2 1996/08/14 06:20:42 mromberg Exp $
+//
 #ifndef _CPUMETER_H_
 #define _CPUMETER_H_
 
-#include "fieldmeter.h"
+#include "fieldmeterdecay.h"
 
-class CPUMeter : public FieldMeter {
+class CPUMeter : public FieldMeterDecay {
 public:
-  CPUMeter( XOSView *parent, int x, int y, int width, int height );
+  CPUMeter( XOSView *parent );
   ~CPUMeter( void );
 
   const char *name( void ) { return "CPUMeter"; }
   void checkevent( void );
+
+  void checkResources(void);
 protected:
-  float cputime_[2][4];
+  float cputime_[2][5];
   int cpuindex_;
 
   void getcputime( void );
