@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: swapmeter.cc,v 1.3 1997/02/26 18:34:59 mromberg Exp $
+// $Id: swapmeter.cc,v 1.6 1997/12/06 01:04:41 mromberg Exp $
 //
 #include "swapmeter.h"
 #include "xosview.h"
@@ -27,6 +27,7 @@ void SwapMeter::checkResources( void ){
   setfieldcolor( 1, parent_->getResource( "swapFreeColor" ) );
   priority_ = atoi (parent_->getResource( "swapPriority" ) );
   dodecay_ = !strcmp (parent_->getResource( "swapDecay" ), "True" );
+  SetUsedFormat( parent_->getResource( "swapUsedFormat" ) );
 }
 
 void SwapMeter::checkevent( void ){
@@ -51,11 +52,11 @@ void SwapMeter::getswapinfo( void ){
       pstat_getswap(&swapinfo, sizeof(swapinfo), 1, i);
       if (swapinfo.pss_idx == (unsigned)i)
           {
-          total_ += swapinfo.pss_nblks;
-          fields_[1] += swapinfo.pss_nfpgs * 4;
+          total_ += (swapinfo.pss_nblksenabled * 1024);
+          fields_[1] += (swapinfo.pss_nfpgs * 4 * 1024);
           }
       }
 
   fields_[0] = total_ - fields_[1];
-  used( (int)((100 * fields_[0]) / total_ ) );
+  setUsed( fields_[0], total_ );
 }
