@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: MeterMaker.cc,v 1.10 1997/03/15 21:03:03 mromberg Exp $
+// $Id: MeterMaker.cc,v 1.13 1998/03/07 21:47:31 mromberg Exp $
 //
 #include "MeterMaker.h"
 #include "xosview.h"
@@ -32,8 +32,12 @@ void MeterMaker::makeMeters(void){
     push(new LoadMeter(_xos));
 
   // Standard meters (usually added, but users could turn them off)
-  if (_xos->isResourceTrue("cpu"))
-    push(new CPUMeter(_xos));
+  if (_xos->isResourceTrue("cpu")){
+    int cpuCount = CPUMeter::countCPUs();
+    int start = (cpuCount == 0) ? 0 : 1;
+    for (int i = start ; i <= cpuCount ; i++)
+      push(new CPUMeter(_xos, CPUMeter::cpuStr(i)));
+  }
   if (_xos->isResourceTrue("mem"))
     push(new MemMeter(_xos));
   if (_xos->isResourceTrue("swap"))
@@ -53,8 +57,12 @@ void MeterMaker::makeMeters(void){
       push(new SerialMeter(_xos, (SerialMeter::Device)i));
 
   // check for the interrupt meter
-  if (_xos->isResourceTrue("interrupts"))
-    push(new IntMeter(_xos));
+  if (_xos->isResourceTrue("interrupts")) {
+    int cpuCount = IntMeter::countCPUs();
+    cpuCount = cpuCount == 0 ? 1 : cpuCount;
+    for (int i = 0 ; i < cpuCount ; i++)
+      push(new IntMeter(_xos, i));
+  }
 
   if (_xos->isResourceTrue("battery"))
     push(new BtryMeter(_xos));
