@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: intmeter.h,v 1.3 1996/12/26 20:18:57 mromberg Exp $
+// $Id: intmeter.h,v 1.4 1998/03/07 21:20:39 mromberg Exp $
 //
 #ifndef _INTMETER_H_
 #define _INTMETER_H_
@@ -13,16 +13,20 @@
 
 class IntMeter : public BitMeter {
 public:
-  IntMeter( XOSView *parent,
-	    const char *title = "", const char *legend ="",
-	    int dolegends = 0, int dousedlegends = 0 );
+  IntMeter( XOSView *parent, int cpu = 0);
   ~IntMeter( void );
 
   void checkevent( void );
 
   void checkResources( void );
+
+  static float getLinuxVersion(void);
+  static int countCPUs(void);
+
 protected:
-  unsigned long irqs_[16], lastirqs_[16];
+  unsigned long irqs_[24], lastirqs_[24];
+  int _cpu;
+  bool _old;
 
   void getirqs( void );
 };
