@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: swapmeter.cc,v 1.3 1997/10/04 02:16:33 mromberg Exp $
+// $Id: swapmeter.cc,v 1.6 1997/12/02 20:03:44 bgrayson Exp $
 //
 
 #include "swapmeter.h"
@@ -14,9 +14,13 @@
 #include <stdlib.h>
 
 #ifdef USESYSCALLS
+#if defined(GNULIBC) || defined(__GLIBC__)
+#include <sys/sysinfo.h>
+#else
 #include <syscall.h>
 #include <linux/kernel.h>
 #endif
+#endif
 
 
 static const char MEMFILENAME[] = "/proc/meminfo";
@@ -37,6 +41,7 @@ void SwapMeter::checkResources( void ){
   setfieldcolor( 1, parent_->getResource( "swapFreeColor" ) );
   priority_ = atoi (parent_->getResource( "swapPriority" ) );
   dodecay_ = !strcmp (parent_->getResource( "swapDecay" ), "True" );
+  SetUsedFormat (parent_->getResource("swapUsedFormat"));
 }
 
 void SwapMeter::checkevent( void ){
@@ -49,7 +54,11 @@ void SwapMeter::checkevent( void ){
 void SwapMeter::getswapinfo( void ){
   struct sysinfo sinfo;
 
+#if defined(GNULIBC) || defined(__GLIBC__)
+  sysinfo(&sinfo);
+#else
   syscall( SYS_sysinfo, &sinfo );
+#endif
 
   total_ = sinfo.totalswap;
   fields_[0] = total_ - sinfo.freeswap;
@@ -62,7 +71,7 @@ void SwapMeter::getswapinfo( void ){
   }
   
   if (total_)
-    used( (int)((100 * fields_[0]) / total_ ) );
+    setUsed (fields_[0], total_);
 }
 #else
 void SwapMeter::getswapinfo( void ){
@@ -98,7 +107,7 @@ void SwapMeter::getswapinfo( void ){
   }
 
   if (total_)
-    used( (int)((100 * fields_[0]) / total_ ) );
+    setUsed (fields_[0], total_);
 }
 #endif
 
