@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: xosview.cc,v 1.9 1997/08/09 01:05:22 bgrayson Exp $
+// $Id: xosview.cc,v 1.13 1998/05/17 21:22:28 bgrayson Exp $
 //
 #include <iostream.h>
 #include <unistd.h>
@@ -15,14 +15,16 @@
 #include "xosview.h"
 #include "meter.h"
 #include "MeterMaker.h"
-#ifdef XOSVIEW_NETBSD
+#if (defined(XOSVIEW_NETBSD) || defined(XOSVIEW_FREEBSD) || defined(XOSVIEW_OPENBSD))
 #include "kernel.h"
 #endif
 
 static const char NAME[] = "xosview@";
 #include "version.cc"
 
-CVSID("$Id: xosview.cc,v 1.9 1997/08/09 01:05:22 bgrayson Exp $");
+int MAX_SAMPLES_PER_SECOND = 10;
+
+CVSID("$Id: xosview.cc,v 1.13 1998/05/17 21:22:28 bgrayson Exp $");
 CVSID_DOT_H(XOSVIEW_H_CVSID);
 
 
@@ -35,8 +37,13 @@ XOSView::XOSView( char * instName, int argc, char *argv[] ) : XWin(),
   //  XWinInit looks at the geometry resource for its geometry.  BCG
   xrm.loadAndMergeResources (argc, argv, display_); 
   XWinInit (argc, argv, NULL, &xrm);
-#ifdef XOSVIEW_NETBSD
-  NetBSDInit();	/*  Needs to be done before processing of -N option.  */
+#if 0	//  Don't enable this yet.
+  MAX_SAMPLES_PER_SECOND = atoi(getResource("samplesPerSec"));
+  if (!MAX_SAMPLES_PER_SECOND)
+    MAX_SAMPLES_PER_SECOND = 10;
+#endif
+#if (defined(XOSVIEW_NETBSD) || defined(XOSVIEW_FREEBSD) || defined(XOSVIEW_OPENBSD))
+  BSDInit();	/*  Needs to be done before processing of -N option.  */
 #endif
 
   checkArgs (argc, argv);  //  Check for any other unhandled args.
@@ -301,7 +308,7 @@ void XOSView::checkArgs (int argc, char** argv) const
 		  argc--;
 		}
 		break;
-#ifdef XOSVIEW_NETBSD
+#if (defined(XOSVIEW_NETBSD) || defined(XOSVIEW_FREEBSD) || defined(XOSVIEW_OPENBSD))
       case 'N': if (strlen(argv[0]) > 2)
       		  SetKernelName(argv[0]+2);
 		else
@@ -312,6 +319,12 @@ void XOSView::checkArgs (int argc, char** argv) const
 		}
 		break;
 #endif
+      case '-':  /*  Check for --version argument.  */
+              if (!strcmp(*argv, "--version")) {
+	        cerr << versionString << endl;
+		exit(0);
+	      }
+	      /*  Fall through to default/error case.  */
       default:
       		cerr << "Ignoring unknown option '" << argv[0] << "'.\n";
 	  	break;
