@@ -4,18 +4,19 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: xosview.h,v 1.5 1997/01/14 18:27:45 bgrayson Exp $
+// $Id: xosview.h,v 1.6 1998/03/27 19:18:17 bgrayson Exp $
 //
 #ifndef _XOSVIEW_H_
 #define _XOSVIEW_H_
 
-#define XOSVIEW_H_CVSID	"$Id: xosview.h,v 1.5 1997/01/14 18:27:45 bgrayson Exp $"
+#define XOSVIEW_H_CVSID	"$Id: xosview.h,v 1.6 1998/03/27 19:18:17 bgrayson Exp $"
 
 #include "xwin.h"
 #include "Xrm.h"  //  For Xrm resource manager class.
 
-#define MAX_SAMPLES_PER_SECOND	10  /*  Take at most n samples per
-					second (default of 10)  */
+
+/*  Take at most n samples per second (default of 10)  */
+extern int MAX_SAMPLES_PER_SECOND;
 
 class Meter;
 
